package com.admost.admost_flutter_plugin;

import android.app.Activity;
import android.util.Log;
import org.json.JSONObject;
import java.util.ArrayList;

import admost.sdk.base.AdMost;
import admost.sdk.base.AdMostConfiguration;
import admost.sdk.base.AdMostLog;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterAdmostPlugin */
public class AdmostFlutterPlugin implements MethodCallHandler {
  /** Plugin registration. */
  private final Activity activity;

  private AdmostFlutterPlugin(Activity activity) {
      this.activity = activity;
  }

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "admost_flutter");
    channel.setMethodCallHandler(new AdmostFlutterPlugin(registrar.activity()));

    final MethodChannel interstitialChannel = new MethodChannel(registrar.messenger(), "admost_flutter/interstitial");
    interstitialChannel.setMethodCallHandler(new AdmostIntersitital(registrar));

    final MethodChannel rewardChannel = new MethodChannel(registrar.messenger(), "admost_flutter/rewarded");
    rewardChannel.setMethodCallHandler(new AdmostRewarded(registrar));

    registrar.platformViewRegistry().registerViewFactory("admost_flutter/banner", new AdmostBannerFactory(registrar.messenger(), registrar.activity()));
  }
    String subjectToGDPR, subjectToCCPA, userConsent;
  @Override
  public void onMethodCall(MethodCall call, final Result result) {
    if (call.method.equals("initialize")) {
        String appId = call.argument("appId");
        AdMostConfiguration.Builder configuration = new AdMostConfiguration.Builder(activity,appId);
        if(call.hasArgument("subjectToGDPR") && call.argument("subjectToGDPR") != null){
            subjectToGDPR = call.argument("subjectToGDPR");
            configuration.setSubjectToGDPR(subjectToGDPR.equals("1"));
        }
        if(call.hasArgument("subjectToCCPA") && call.argument("subjectToCCPA") != null){
            subjectToCCPA = call.argument("subjectToCCPA");
            configuration.setSubjectToCCPA(subjectToCCPA.equals("1"));
        }
        if(call.hasArgument("userConsent") && call.argument("userConsent") != null){
            userConsent =  call.argument("userConsent");
            configuration.setUserConsent(userConsent.equals("1"));
        }

        AdMost.getInstance().init(configuration.build());



    } else if (call.method.equals("startTestSuite")) {
            AdMost.getInstance().startTestSuite();
    } else if (call.method.equals("isPrivacyConsentRequired")) {
            AdMost.getInstance().setPrivacyConsentListener(activity, new AdMost.PrivacyConsentListener() {
                @Override
                public void isPrivacyConsentRequired(String s) {
                    result.success(s);
                }
            });
    } else if (call.method.equals("trackIAP")) {
        try {
            String originalJSON = call.argument("originalJSON");
            String signature = call.argument("signature");
            String currencyCode = call.argument("currencyCode");
            Double price = call.argument("price");
            ArrayList<String> tags = call.argument("tags");

            String[] tagsToSend = null;
            if (tags != null) {
                tagsToSend = tags.toArray(new String[0]);
            }
            trackIAP(originalJSON, signature, currencyCode, price, tagsToSend);

        } catch (Exception ex) {
            ex.printStackTrace();
            Log.w("ADMOST", "argument exception");
        }

    } else if (call.method.equals("setUserId")) {
        String userId = call.argument("userId");
        AdMost.getInstance().setUserId(userId);
    }

  }

    private void trackIAP(String originalJSON, String signature, String isoCurrencyCode, Double price, final String[] tags) {

        double localizedPriceDoubleInMicros = price * 1000000;
        final String toSendSku = "{\"price_amount_micros\":" + localizedPriceDoubleInMicros + ",\"price_currency_code\":\"" + isoCurrencyCode + "\"}";
        if(originalJSON.length()>0 && signature.length()>0) {
            AdMost.getInstance().trackIAP(originalJSON, signature, toSendSku, tags, false);
        }else{
            Log.w("ADMOST", "Something wrong with your data");
        }

    }
}
