package com.admost.admost_flutter_plugin;

import android.util.Log;

import java.util.HashMap;

import admost.sdk.AdMostInterstitial;
import admost.sdk.listener.AdMostAdListener;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

public class AdmostIntersitital implements MethodCallHandler {

  private final Registrar registrar;
  private AdMostInterstitial interstitial;

  public AdmostIntersitital(Registrar registrar) {
      this.registrar= registrar;
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
      if (call.method.equals("load")) {

          String zoneId = call.argument("zoneId");
          int id = call.argument("id");
          final MethodChannel methodChannel = new MethodChannel(registrar.messenger(), "admost_flutter/interstitial_" + id);
          interstitial = new AdMostInterstitial(registrar.activity(), zoneId, new AdMostAdListener() {
              @Override
              public void onDismiss(String message) {
                  // It indicates that the interstitial ad is closed by clicking cross button/back button
                  methodChannel.invokeMethod(AdmostAdEvents.dismissed,null);
              }
              @Override
              public void onFail(int errorCode) {
                  // It indicates that the interstitial ad received no-fill response from all of its placements.
                  // Therefore, the ad can not be shown.
                  // Warning: Attempting to load a new ad from the onFail() methods is strongly discouraged.
                  // If you must load an ad from onFail() ensure to limit ad load retries to avoid continuous
                  // failed ad requests in situations such as limited network connectivity.
                  if(errorCode == 301 || errorCode == 302 || errorCode == 305){
                    HashMap<String,Object> arguments = new HashMap<>();
                    arguments.put("errorCode", errorCode);
                    arguments.put("errorMessage", errorCode);
                    methodChannel.invokeMethod(AdmostAdEvents.failedToShow,arguments);
                  } else {
                    HashMap<String,Object> arguments = new HashMap<>();
                    arguments.put("errorCode", errorCode);
                    arguments.put("errorMessage", errorCode);
                    methodChannel.invokeMethod(AdmostAdEvents.failedToLoad,arguments);
                  }
              }
              @Override
              public void onReady(String network, int ecpm) {
                  // It indicates that the interstitial ad is loaded and ready to show.
                  HashMap<String,Object> arguments = new HashMap<>();
                  arguments.put("network", network);
                  arguments.put("ecpm", ecpm);
                  methodChannel.invokeMethod(AdmostAdEvents.loaded,arguments);
              }
              @Override
              public void onShown(String network) {
                  // It indicates that the loaded interstitial ad is shown to the user.
                  HashMap<String,Object> arguments = new HashMap<>();
                  arguments.put("network", network);
                  methodChannel.invokeMethod(AdmostAdEvents.opened,arguments);
              }
              @Override
              public void onClicked(String s) {
                  // It indicates that the interstitial ad is clicked.
                  HashMap<String,Object> arguments = new HashMap<>();
                  arguments.put("network", s);
                  methodChannel.invokeMethod(AdmostAdEvents.clicked, arguments);
              }

              @Override
              public void onStatusChanged(int i) {
                  //It indicates that capping status is changed.
                  HashMap<String,Object> arguments = new HashMap<>();
                  arguments.put("status", i);
                  methodChannel.invokeMethod(AdmostAdEvents.statusChanged, arguments);
              }

              @Override
              public void onComplete(String s) {
                  // If you are using interstitial, this callback will not be triggered.
              }

          });

          interstitial.refreshAd(false);

      } else if (call.method.equals("show")) {
          if (interstitial != null && interstitial.isLoaded()) {
              interstitial.show();
          } else {
              Log.e("ADMOST","not loaded yet");
          }
      }  else if (call.method.equals("isLoaded")) {
          result.success(interstitial != null && interstitial.isLoaded());
      }
  }
}
